#include <iostream>
#include <cmath>

constexpr unsigned long long factorial(unsigned n) {
    return (n == 0 || n == 1) ? 1 : n * factorial(n - 1);
}

constexpr unsigned long long max_factorial = factorial(8); // 20

constexpr double compute_sin(double x, unsigned long long n) {
    double sum = 0.0;

    for (unsigned long long i = 0; i < n; ++i) {
        double term = std::pow(-1, i) * std::pow(x, 2 * i + 1) / static_cast<double>(factorial(2 * i + 1));
        sum += term;
    }

    return sum;
}

int main() {
    constexpr size_t num_iterations = 10;
    constexpr double step = 2 * M_PI / num_iterations;


    double total_sum = 0.0;
    for (size_t i = 0; i < num_iterations; ++i) {
        double x = step * i;
        total_sum += compute_sin(x, max_factorial);
    }


    return 0;
}